# Put in a separate page so it can be used by SciMLDocs.jl

pages = [
    "Home" => "index.md",
    "matrix_exponentials.md",
    "expv.md",
    "arnoldi.md",
]
